@@ -3,16 +3,17 @@ function(x, y = NULL, z = NULL, color = par("col"),
      main = NULL, sub = NULL, xlim = NULL, ylim = NULL, zlim = NULL,
      xlab = NULL, ylab = NULL, zlab = NULL, scale.y = 1, angle = 40,
      axis = TRUE, tick.marks = TRUE, label.tick.marks = TRUE, 
-     x.ticklabs = NULL, y.ticklabs = NULL, z.ticklabs = NULL, 
-     grid = TRUE, box = TRUE, lab = par("lab"), lab.z = mean(lab[1:2]),  
-     type = par("type"), highlight.3d = FALSE, mar = c(5, 3, 4, 3) + 0.1,
-     col.axis = par("col.axis"), col.grid= "grey", col.lab= par("col.lab"),
+     x.ticklabs = NULL, y.ticklabs = NULL, z.ticklabs = NULL,
+     y.margin.add = 0, grid = TRUE, box = TRUE, lab = par("lab"),
+     lab.z = mean(lab[1:2]), type = par("type"), highlight.3d = FALSE,
+     mar = c(5, 3, 4, 3) + 0.1, col.axis = par("col.axis"),
+     col.grid= "grey", col.lab= par("col.lab"),
      cex.axis = par("cex.axis"), cex.lab = 0.8 * par("cex.lab"),
      font.axis = par("font.axis"), font.lab = par("font.lab"),
      lty.axis = par("lty"), lty.grid = par("lty"), log = "", ...) 
      # log not yet implemented
 { 
-    ##  scatterplot3d, 0.3.4, 08.01.2001,
+    ##  scatterplot3d, 0.3-5, 08.03.2001,
     ##  Uwe Ligges <ligges@statistik.uni-dortmund.de>,
     ##      http://www.statistik.uni-dortmund.de/leute/ligges.htm
     ##
@@ -26,6 +27,8 @@ function(x, y = NULL, z = NULL, color = par("col"),
     ## 0.3.3: new argument "mar", more details in the help files
     ## 0.3.4: new arguments x/y/z.ticklabs, thanks to Ben Bolker!
     ##        bug fix: adj for tick.mark.labels corrected
+    ## 0.3-5: new argument y.margin.add for manual fixing scaling problems
+    ##        (e.g. some y-tickmarks dissapear after rescaling the window)
     
     ## UNfixed bugs:
     ##        - pch doesn't work vectorized because of y-sorting 
@@ -149,8 +152,8 @@ function(x, y = NULL, z = NULL, color = par("col"),
     else        {x1 <- x.min; x2 <- x.max + yx.f * y.max}
     plot.window(c(x1, x2), c(z.min, z.max + yz.f * y.max))
     temp <- strwidth(as.character(y.scal * y.max + round(y.add, 0)), cex=cex.lab)
-    if(angle.2) x1 <- x1 - temp
-    else x2 <- x2 + temp
+    if(angle.2) x1 <- x1 - temp - y.margin.add
+    else x2 <- x2 + temp + y.margin.add
     plot.window(c(x1, x2), c(z.min, z.max + yz.f * y.max))
     if(angle > 2) par("usr" = par("usr")[c(2, 1, 3:4)])
     title(main, sub, ...)
